
import com.examples.xmlstring.clientbindings.*;

import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import java.io.*;
import java.util.Calendar;


public class WSDLClient {

    public static void main(String[] args) throws Exception {
        String url = "http://localhost:9090/xmlstring/jaxrpc";
        if (args.length == 1) {
            url = args[0];
        }
        XMLStringService_Impl serviceproxy = new XMLStringService_Impl();
        IStringService_Stub stub = (IStringService_Stub) (serviceproxy.getIStringServicePort());
        stub._setProperty(javax.xml.rpc.Stub.ENDPOINT_ADDRESS_PROPERTY, url);
        sendString(XML, stub);
//      sendString("Hello World", stub);
        sendStringFromFile("bidrequest.xml", stub);
    }


    /**
     * Sends the contents to the service, the contents are stored in the String below
     *
     * @param xml
     * @param stub
     * @throws Exception
     */
    public static void sendString(String xml, IStringService_Stub stub) throws Exception {
        SayXMLHello request = new SayXMLHello(xml);
        SayXMLHelloResponse response = stub.sayXMLHello(request);
        System.out.println("Server replied back with : \n " + response.getResult());

    }

    /**
     * Sends the contents to the service after reading from a file
     *
     * @param filename
     * @param stub
     * @throws Exception
     */
    public static void sendStringFromFile(String filename, IStringService_Stub stub) throws Exception {
        SayXMLHello request = new SayXMLHello(readStringFromFileRaw(filename));
        SayXMLHelloResponse response = stub.sayXMLHello(request);
        System.out.println("Server replied back with : \n " + response.getResult());

    }

    /**
     * Reads the contents form a file and returns a String
     *
     * @param filename
     * @return
     * @throws Exception
     */
    private static String readStringFromFileRaw(String filename) throws Exception {
        StringBuffer sb = new StringBuffer();
        BufferedReader br = new BufferedReader(new InputStreamReader(new FileInputStream(filename)));
        String input = br.readLine();
        while (input != null) {
            sb.append(input);
            input = br.readLine();
        }
        br.close();
        String contents = sb.toString();
        System.out.println("Read String from file \n " + contents);
        return contents;
    }


    private static String XML = "<payload>\n" +
            "\t<BidRequest BidId=\"123654\" DueDate=\"2004-05-01\" xmlns:n=\"http://bidservice.com\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"BidRequest.xsd\">\n" +
            "\t\t<Company Name=\"Small Time Shipping\" id=\"10001\" url=\"www.BigTimeShipping.com\" phone=\"888-920-9817\">\n" +
            "\t\t\t<Address Street=\"Small Ship Lane\" City=\"Oceanana\" State=\"MD\" Zip=\"20819\"/>\n" +
            "\t\t\t<BiddingAgent Name=\"Joe Bid Agent\" Email=\"joe@shipping.com\" Phone=\"888-890-1789\"/>\n" +
            "\t\t</Company>\n" +
            "\t\t<Manifest>\n" +
            "\t\t\t<PickupPortOfCall Port=\"Miami\" Date=\"2003-10-09\" Time=\"Morning\"/>\n" +
            "\t\t\t<DeliveryPortOfCall Port=\"Athens\" Date=\"2003-12-01\" Time=\"Afternoon\"/>\n" +
            "\t\t\t<Cargo>\n" +
            "\t\t\t\t<ContainerSet Size=\"Small\" IsRefridgerated=\"true\" Quantity=\"10\"/>\n" +
            "\t\t\t\t<ContainerSet Size=\"Medium\" IsRefridgerated=\"false\" Quantity=\"2\"/>\n" +
            "\t\t\t\t<ContainerSet Size=\"Large\" IsRefridgerated=\"false\" Quantity=\"3\"/>\n" +
            "\t\t\t</Cargo>\n" +
            "\t\t</Manifest>\n" +
            "\t</BidRequest>\n" +
            "</payload>";

}
